==> openigtlink_1.11.0.orig.tar.gz: openigtlink-1.11.0/Testing/igtlutil/igtl_test_data_position.h <==
/*=========================================================================

  Program:   OpenIGTLLink Library -- Dummy position data
  Module:    $RCSfile: $
  Language:  C
  Date:      $Date: $
  Version:   $Revision: $

  Copyright (c) Insight Software Consortium. All rights reserved.

  This software is distributed WITHOUT ANY WARRANTY; without even
  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the above copyright notices for more information.

=========================================================================*/

#ifndef __IGTL_TEST_DATA_POSITION_H
#define __IGTL_TEST_DATA_POSITION_H

char test_position_message[] = {

  /*-------- OpenIGTLink message header -------*/
  0x00, 0x01,                                     /* Version number */
  0x50, 0x4f, 0x53, 0x49, 0x54, 0x49, 0x4f, 0x4e,
  0x00, 0x00, 0x00, 0x00,                         /* POSITION */ 
  0x44, 0x65, 0x76, 0x69, 0x63, 0x65, 0x4e, 0x61,
  0x6d, 0x65, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Device name */
  0x00, 0x00, 0x00, 0x00, 0x49, 0x96, 0x02, 0xd2, /* Time stamp */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, /* Body size */
  0x6b, 0xc8, 0xd6, 0x28, 0x2b, 0x79, 0xa3, 0xa1, /* CRC */

  /*-------- POSITION message body -------*/
  
  0x42, 0x38, 0x36, 0x60, 0x41, 0x9b, 0xc4, 0x67, /* px, py */
  0x42, 0x38, 0x36, 0x60, 0x00, 0x00, 0x00, 0x00, /* pz, ox */
  0x3f, 0x13, 0xcd, 0x3a, 0x3f, 0x13, 0xcd, 0x3a, /* oy, oz */
  0x3e, 0xaa, 0xaa, 0xab,                         /* ow     */

};

#endif /* IGTL_TEST_DATA_POSITION_H */

==> openigtlink_3.0.0.orig.tar.gz: openigtlink-3.0.0/Testing/igtlutil/igtl_test_data_position.h <==
/*=========================================================================

  Program:   OpenIGTLLink Library -- Dummy position data
  Module:    $RCSfile: $
  Language:  C
  Date:      $Date: $
  Version:   $Revision: $

  Copyright (c) Insight Software Consortium. All rights reserved.

  This software is distributed WITHOUT ANY WARRANTY; without even
  the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
  PURPOSE.  See the above copyright notices for more information.

=========================================================================*/

#ifndef __IGTL_TEST_DATA_POSITION_H
#define __IGTL_TEST_DATA_POSITION_H

unsigned char test_position_message[] = {

  /*-------- OpenIGTLink message header -------*/
  0x00, 0x01,                                     /* Version number */
  0x50, 0x4f, 0x53, 0x49, 0x54, 0x49, 0x4f, 0x4e,
  0x00, 0x00, 0x00, 0x00,                         /* POSITION */ 
  0x44, 0x65, 0x76, 0x69, 0x63, 0x65, 0x4e, 0x61,
  0x6d, 0x65, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00,
  0x00, 0x00, 0x00, 0x00,                         /* Device name */
  0x00, 0x00, 0x00, 0x00, 0x49, 0x96, 0x02, 0xd4, /* Time stamp */
  0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x1c, /* Body size */
  0x6b, 0xc8, 0xd6, 0x28, 0x2b, 0x79, 0xa3, 0xa1, /* CRC */

  /*-------- POSITION message body -------*/
  
  0x42, 0x38, 0x36, 0x60, 0x41, 0x9b, 0xc4, 0x67, /* px, py */
  0x42, 0x38, 0x36, 0x60, 0x00, 0x00, 0x00, 0x00, /* pz, ox */
  0x3f, 0x13, 0xcd, 0x3a, 0x3f, 0x13, 0xcd, 0x3a, /* oy, oz */
  0x3e, 0xaa, 0xaa, 0xab,                         /* ow     */

};

#endif /* IGTL_TEST_DATA_POSITION_H */
